Polymarket WebSocket client and types
This module provides a WebSocket client for connecting to Polymarket’s real-time market data stream, along with all the data types for messages and updates received over the WebSocket connection.
Re-exports
pub use messages::Auth;pub use messages::SubscribedMessage;pub use messages::SubscriptionMessage;pub use messages::UpdateSubscriptionMessage;pub use types::ErrorMessage;pub use types::OrderUpdate;pub use types::OrderbookUpdate;pub use types::PriceLevel;pub use types::PriceUpdate;pub use types::TradeUpdate;
Modules
Structs
- Polymarket
WebSocket - WebSocket client for connecting to Polymarket’s market data stream
Enums
- WebSocket
Message - Main WebSocket message enum that can represent any message type received from the API